@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20201020';
+our $VERSION = '5.20201120';
 our %utilities;
 
 sub utilities {
@@ -1650,6 +1650,13 @@ my %delta = (
         removed => {
         }
     },
+    5.033004 => {
+        delta_from => 5.033003,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
